@@ -19,10 +19,10 @@
 from __future__ import print_function
 
 import os
-import StringIO
 import sys
 import tempfile
 
+from d2to1.extern import six
 import fixtures
 import testscenarios
 
@@ -156,12 +156,13 @@ class GitLogsTest(tests.BaseTestCase):
 
     def test_write_git_changelog(self):
         exist_files = [os.path.join(self.root_dir, f)
-                       for f in ".git", ".mailmap"]
+                       for f in (".git", ".mailmap")]
         self.useFixture(fixtures.MonkeyPatch(
             "os.path.exists",
             lambda path: os.path.abspath(path) in exist_files))
         self.useFixture(fixtures.FakePopen(lambda _: {
-            "stdout": StringIO.StringIO("Author: Foo Bar <email@bar.com>\n")
+            "stdout": six.BytesIO("Author: Foo Bar "
+                                  "<email@bar.com>\n".encode('utf-8'))
         }))
 
         def _fake_read_git_mailmap(*args):
@@ -179,8 +180,8 @@ class GitLogsTest(tests.BaseTestCase):
     def _fake_log_output(self, cmd, mapping):
         for (k, v) in mapping.items():
             if cmd.startswith(k):
-                return v
-        return ""
+                return v.encode('utf-8')
+        return b""
 
     def test_generate_authors(self):
         author_old = "Foo Foo <email@foo.com>"
@@ -202,7 +203,7 @@ class GitLogsTest(tests.BaseTestCase):
             lambda path: os.path.abspath(path) in exist_files))
 
         self.useFixture(fixtures.FakePopen(lambda proc_args: {
-            "stdout": StringIO.StringIO(
+            "stdout": six.BytesIO(
                 self._fake_log_output(proc_args["args"][2], cmd_map))
         }))
 
@@ -243,7 +244,7 @@ class BuildSphinxTest(tests.BaseTestCase):
         self.distr.command_options["build_sphinx"] = {
             "source_dir": ["a", "."]}
         pkg_fixture = fixtures.PythonPackage(
-            "fake_package", [("fake_module.py", "")])
+            "fake_package", [("fake_module.py", b"")])
         self.useFixture(pkg_fixture)
         self.useFixture(DiveDir(pkg_fixture.base))
 
@@ -280,12 +281,24 @@ class ParseRequirementsTest(tests.BaseTestCase):
         self.assertEqual(['bar'],
                          packaging.parse_requirements([self.tmp_file]))
 
+    def test_parse_requirements_with_versioned_git_egg_url(self):
+        with open(self.tmp_file, 'w') as fh:
+            fh.write("-e git://foo.com/zipball#egg=bar-1.2.4")
+        self.assertEqual(['bar>=1.2.4'],
+                         packaging.parse_requirements([self.tmp_file]))
+
     def test_parse_requirements_with_http_egg_url(self):
         with open(self.tmp_file, 'w') as fh:
             fh.write("https://foo.com/zipball#egg=bar")
         self.assertEqual(['bar'],
                          packaging.parse_requirements([self.tmp_file]))
 
+    def test_parse_requirements_with_versioned_http_egg_url(self):
+        with open(self.tmp_file, 'w') as fh:
+            fh.write("https://foo.com/zipball#egg=bar-4.2.1")
+        self.assertEqual(['bar>=4.2.1'],
+                         packaging.parse_requirements([self.tmp_file]))
+
     def test_parse_requirements_removes_index_lines(self):
         with open(self.tmp_file, 'w') as fh:
             fh.write("-f foobar")
